==> emacspeak-27.0.tar.bz2: emacspeak-27.0/lisp/flite-voices.el <==
;;; flite.el --- Emacspeak FLite
;;; $Id: flite-voices.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
;;; $Author: tv.raman.tv $
;;; Description:  FLite interface 
;;; Keywords: Emacspeak,  Audio Desktop FLite
;;{{{  LCD Archive entry:

;;; LCD Archive Entry:
;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
;;; A speech interface to Emacs |
;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
;;;  $Revision: 4532 $ |
;;; Location undetermined
;;;

;;}}}
;;{{{  Copyright:
;;;Copyright (C) 1995 -- 2007, T. V. Raman 
;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
;;; All Rights Reserved.
;;;
;;; This file is not part of GNU Emacs, but the same permissions apply.
;;;
;;; GNU Emacs is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2, or (at your option)
;;; any later version.
;;;
;;; GNU Emacs is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Emacs; see the file COPYING.  If not, write to
;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;}}}
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;{{{  introduction

;;; defines interactive command tts-flite that launches eflite 
;;; this will be updated to use the FLite TCL server when that is complete.
;;; http://sf.net/projects/eflite
;;; as the tts server.
;;; When and if eflite becomes capable of voice locking,
;;; this file should provide code similar to  outloud-voices.el

;;}}}
;;{{{  Required modules

(require 'cl)
(declaim  (optimize  (safety 0) (speed 3)))
(require 'custom)

;;}}}
;;;###autoload
;;{{{  launch eflite 
;;;###autoload
(defun tts-eflite ()
  "Use eflite TTS server."
  (interactive)
  (let ((dtk-program "eflite"))
    (tts-restart)
    (message "This is Emacspeak! ")))

;;}}}

(provide 'flite-voices)
;;{{{ end of file

;;; local variables:
;;; folded-file: t
;;; byte-compile-dynamic: t
;;; end:

;;}}}

==> emacspeak_40.0+dfsg.orig.tar.bz2: emacspeak-40.0+dfsg/lisp/flite-voices.el <==
;;; flite.el --- Emacspeak FLite
;;; $Id: flite-voices.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
;;; $Author: tv.raman.tv $
;;; Description:  FLite interface 
;;; Keywords: Emacspeak,  Audio Desktop FLite
;;{{{  LCD Archive entry:

;;; LCD Archive Entry:
;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
;;; A speech interface to Emacs |
;;; $Date: 2008-07-06 10:18:30 -0700 (Sun, 06 Jul 2008) $ |
;;;  $Revision: 4532 $ |
;;; Location undetermined
;;;

;;}}}
;;{{{  Copyright:
;;;Copyright (C) 1995 -- 2011, T. V. Raman 
;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
;;; All Rights Reserved.
;;;
;;; This file is not part of GNU Emacs, but the same permissions apply.
;;;
;;; GNU Emacs is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2, or (at your option)
;;; any later version.
;;;
;;; GNU Emacs is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Emacs; see the file COPYING.  If not, write to
;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;}}}
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;{{{  introduction

;;; defines interactive command tts-flite that launches eflite 
;;; this will be updated to use the FLite TCL server when that is complete.
;;; http://sf.net/projects/eflite
;;; as the tts server.
;;; When and if eflite becomes capable of voice locking,
;;; this file should provide code similar to  outloud-voices.el

;;}}}
;;{{{  Required modules

(require 'cl)
(declaim  (optimize  (safety 0) (speed 3)))
(require 'custom)

;;}}}
;;;###autoload
;;{{{  launch eflite 
;;;###autoload
(defun tts-eflite ()
  "Use eflite TTS server."
  (interactive)
  (let ((dtk-program "eflite"))
    (tts-restart)
    (message "This is Emacspeak! ")))

(defun flite-configure-tts ()
  (dectalk-configure-tts)
  (dtk-unicode-update-untouched-charsets '(ascii latin-iso8859-1 eight-bit-graphic)))

;;}}}

(provide 'flite-voices)
;;{{{ end of file

;;; local variables:
;;; folded-file: t
;;; byte-compile-dynamic: nil
;;; end:

;;}}}
